'use strict';
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var server_types_1 = require("./server-types");
/**
 * Inform that a new resource was created. Server will
 * add a Location header and set status to 201
 */
var NewResource = (function (_super) {
    __extends(NewResource, _super);
    /**
     * Constructor. Receives the location of the new resource created.
     * @param location To be added to the Location header on response
     * @param body To be added to the response body
     */
    function NewResource(location, body) {
        return _super.call(this, location, 201, body) || this;
    }
    return NewResource;
}(server_types_1.ReferencedResource));
exports.NewResource = NewResource;
/**
 * Inform that the request was accepted but is not completed.
 * A Location header should inform the location where the user
 * can monitor his request processing status.
 */
var RequestAccepted = (function (_super) {
    __extends(RequestAccepted, _super);
    /**
     * Constructor. Receives the location where information about the
     * request processing can be found.
     * @param location To be added to the Location header on response
     * @param body To be added to the response body
     */
    function RequestAccepted(location, body) {
        return _super.call(this, location, 202, body) || this;
    }
    return RequestAccepted;
}(server_types_1.ReferencedResource));
exports.RequestAccepted = RequestAccepted;
/**
 * Inform that the resource has permanently
 * moved to a new location, and that future references should use a
 * new URI with their requests.
 */
var MovedPermanently = (function (_super) {
    __extends(MovedPermanently, _super);
    /**
     * Constructor. Receives the location where the resource can be found.
     * @param location To be added to the Location header on response
     * @param body To be added to the response body
     */
    function MovedPermanently(location, body) {
        return _super.call(this, location, 301, body) || this;
    }
    return MovedPermanently;
}(server_types_1.ReferencedResource));
exports.MovedPermanently = MovedPermanently;
/**
 * Inform that the resource has temporarily
 * moved to another location, but that future references should
 * still use the original URI to access the resource.
 */
var MovedTemporarily = (function (_super) {
    __extends(MovedTemporarily, _super);
    /**
     * Constructor. Receives the location where the resource can be found.
     * @param location To be added to the Location header on response
     * @param body To be added to the response body
     */
    function MovedTemporarily(location, body) {
        return _super.call(this, location, 302, body) || this;
    }
    return MovedTemporarily;
}(server_types_1.ReferencedResource));
exports.MovedTemporarily = MovedTemporarily;
/**
 * Used to download a resource.
 */
var DownloadResource = (function () {
    /**
     * Constructor.
     * @param filePath The file path to download.
     * @param fileName The file name
     */
    function DownloadResource(filePath, fileName) {
        this.filePath = filePath;
        this.fileName = fileName;
    }
    return DownloadResource;
}());
exports.DownloadResource = DownloadResource;
/**
 * Used to download binary data as a file.
 */
var DownloadBinaryData = (function () {
    /**
     * Constructor. Receives the location of the resource.
     * @param content The binary data to be downloaded as a file.
     * @param mimeType The mime-type to be passed on Content-Type header.
     * @param fileName The file name
     */
    function DownloadBinaryData(content, mimeType, fileName) {
        this.content = content;
        this.mimeType = mimeType;
        this.fileName = fileName;
    }
    return DownloadBinaryData;
}());
exports.DownloadBinaryData = DownloadBinaryData;
//# sourceMappingURL=server-return.js.map